<?php
namespace Magenest\Salesforce\Controller\Adminhtml\Sync;

use Magenest\Salesforce\Helper\Data;
use Magenest\Salesforce\Model\Sync;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Config\Storage\WriterInterface;
use Magento\Framework\Controller\Result\Redirect;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Controller\ResultInterface;
use Magento\Framework\Serialize\Serializer\Serialize;

class Queue extends \Magento\Backend\App\Action
{
    /**
     * @var Sync\Contact
     */
    protected $_contact;

    /**
     * @var Sync\Campaign
     */
    protected $_campaign;

    /**
     * @var Sync\Account
     */
    protected $_account;

    /**
     * @var Sync\Lead
     */
    protected $_lead;

    /**
     * @var Sync\Order
     */
    protected $_order;

    /**
     * @var Sync\Product
     */
    protected $_product;

    /**
     * @var Sync\Opportunity
     */
    protected $_opportunity;

    /**
     * @var Serialize
     */
    protected $_serializer;

    /**
     * @var Sync\Subscriber
     */
    private $_subscriber;

    /**
     * @var WriterInterface
     */
    private $writer;

    /**
     * @param Context $context
     * @param Sync\Contact $contact
     * @param Sync\Campaign $campaign
     * @param Sync\Account $account
     * @param Sync\Lead $lead
     * @param Sync\Order $order
     * @param Sync\Product $product
     * @param Sync\Opportunity $opportunity
     * @param Sync\Subscriber $subscriber
     * @param Serialize $serialize
     * @param WriterInterface $writer
     */
    public function __construct(
        Context          $context,
        Sync\Contact     $contact,
        Sync\Campaign    $campaign,
        Sync\Account     $account,
        Sync\Lead        $lead,
        Sync\Order       $order,
        Sync\Product     $product,
        Sync\Opportunity $opportunity,
        Sync\Subscriber  $subscriber,
        Serialize        $serialize,
        WriterInterface  $writer
    ) {
        parent::__construct($context);
        $this->writer         = $writer;
        $this->_contact       = $contact;
        $this->_campaign      = $campaign;
        $this->_account       = $account;
        $this->_lead          = $lead;
        $this->_order         = $order;
        $this->_product       = $product;
        $this->_opportunity   = $opportunity;
        $this->_subscriber    = $subscriber;
        $this->_serializer    = $serialize;
    }

    /**
     * @return Redirect|ResultInterface
     */
    public function execute()
    {
        $this->writer->save(Data::QUEUE_LOCK, 1);

        try {
            /** Sync Queue */
            $this->_account->massSyncQueue();

            $this->_contact->syncAllQueue();

            $this->_lead->syncAllQueue();

            $this->_campaign->syncAllQueue();

            $this->_product->syncAllQueue();

            $this->_order->syncAllQueue();

            $this->_opportunity->syncAllQueue();

            $this->_subscriber->syncAllQueue();

            $this->messageManager->addSuccessMessage(
                __('All items in queue are synced. Check out Reports for result.')
            );
        } catch (\Throwable $e) {
            $this->messageManager->addErrorMessage(
                __(
                    'Something happen during syncing process. Detail: %1. Trace: %2.',
                    $e->getMessage(),
                    $e->getTraceAsString()
                )
            );
        }

        $this->writer->save(Data::QUEUE_LOCK, 0);
        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        $resultRedirect->setUrl($this->_redirect->getRefererUrl());
        return $resultRedirect;
    }

    /**
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Magenest_Salesforce::config_salesforce');
    }
}
